featureflags.api package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   featureflags.api.default

Submodules
----------

featureflags.api.client module
------------------------------

.. automodule:: featureflags.api.client
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.api.types module
-----------------------------

.. automodule:: featureflags.api.types
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: featureflags.api
   :members:
   :undoc-members:
   :show-inheritance:
